| Title: | Access 'INVEKOS' API for Field Polygons |
|---|---|
| Description: | A 'shiny' app that allows to access and use the 'INVEKOS' API for field polygons in Austria. API documentation is available at <https://gis.lfrz.gv.at/api/geodata/i009501/ogc/features/v1/>. |
| Authors: | Sebastian Wieser [aut, cre, cph] (ORCID: <https://orcid.org/0009-0008-8940-7937>) |
| Maintainer: | Sebastian Wieser <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.0.2.9000 |
| Built: | 2026-05-25 07:24:19 UTC |
| Source: | https://github.com/farmse988/poly4at |
A simple feature collection representing the boundary of Austria.
austria_boundaryaustria_boundary
A simple feature collection (sf) with 1 feature and 1 field:
Feature ID, a unique identifier for the feature.
A POLYGON representing the boundary of Austria.
Launches the Poly4AT Shiny application for querying geographic data based on coordinates.
poly4AT_processor()poly4AT_processor()
A Shiny application.
## Not run: poly4AT_processor() ## End(Not run)## Not run: poly4AT_processor() ## End(Not run)